@@ -1,10 +1,11 @@
 """Pipeline tests for complete DFM/DDFM workflows.
 
 This module tests the complete pipeline from configuration loading,
-data loading (with statistics extraction), model training, to prediction and nowcasting.
+data loading (with preprocessing pipeline), model training, to prediction and nowcasting.
 
-Note: Data must be preprocessed by users before passing to DataModule.
-The transformer parameter is used to extract statistics (Mx/Wx) for forecasting/nowcasting.
+Note: Users can provide either raw data with a preprocessing pipeline (recommended) or
+preprocessed data. When a pipeline is provided, preprocessing happens automatically in setup().
+The pipeline is also used to extract statistics (Mx/Wx) for forecasting/nowcasting.
 
 Test Structure:
 - TestDFMPipeline: Tests for linear Dynamic Factor Model (DFM) pipeline
@@ -57,7 +58,8 @@ class TestDFMPipeline:
     4. Prediction and forecasting
     5. Complete end-to-end workflow
     
-    Note: Data must be preprocessed by users. Transformer extracts statistics (Mx/Wx).
+    Note: Users can provide raw data with a preprocessing pipeline (preprocessing happens in setup()),
+    or preprocessed data. The pipeline also extracts statistics (Mx/Wx) for forecasting/nowcasting.
     
     All tests use actual data and config files when available.
     """
@@ -103,8 +105,8 @@ class TestDFMPipeline:
     def test_dfm_pipeline_data_loading(self, test_data_path, test_dfm_config_path, simple_transformer):
         """Test step 2: Data loading with transformer for statistics extraction.
         
-        Note: Data must be preprocessed by user before passing to DataModule.
-        Transformer is used to extract statistics (Mx/Wx) for forecasting/nowcasting.
+        Note: Users can provide raw data with a preprocessing pipeline (preprocessing happens in setup()),
+        or preprocessed data. The pipeline also extracts statistics (Mx/Wx) for forecasting/nowcasting.
         """
         check_test_files_exist(test_data_path, test_dfm_config_path)
         
@@ -112,7 +114,8 @@ class TestDFMPipeline:
         config = load_config_only_safely(test_dfm_config_path, model_type="DFM")
         
         # Create DataModule
-        # Note: Data should be preprocessed by user. Transformer extracts statistics.
+        # Note: Raw data + pipeline pattern - preprocessing happens in setup().
+        # Pipeline also extracts statistics (Mx/Wx) for forecasting/nowcasting.
         assert config is not None
         data_module = DFMDataModule(
             config=config,
@@ -274,7 +277,7 @@ class TestDFMPipeline:
         
         assert model.config is not None
         
-        # Step 2: Load data from CSV (data should be preprocessed by user)
+        # Step 2: Load data from CSV (raw data - preprocessing happens in setup() via pipeline)
         data_module = DFMDataModule(
             config=model.config,
             pipeline=simple_transformer,
@@ -341,7 +344,8 @@ class TestDFMPipeline:
     def test_dfm_pipeline_with_columnwise_transformer(self, test_data_path, test_dfm_config_path, columnwise_transformer):
         """Test complete pipeline with StandardScaler transformer for statistics extraction.
         
-        Note: Data must be preprocessed by user. Transformer extracts Mx/Wx statistics.
+        Note: Users can provide raw data with a preprocessing pipeline (preprocessing happens in setup()),
+        or preprocessed data. The pipeline also extracts Mx/Wx statistics.
         """
         check_test_files_exist(test_data_path, test_dfm_config_path)
         
@@ -352,7 +356,7 @@ class TestDFMPipeline:
         assert model.config is not None
         
         # Step 2: Load data with transformer to extract statistics (Mx/Wx from StandardScaler)
-        # Note: Data should be preprocessed by user before this step
+        # Note: Raw data + pipeline pattern - preprocessing happens in setup()
         data_module = DFMDataModule(
             config=model.config,
             pipeline=columnwise_transformer,  # Extracts Mx/Wx statistics
@@ -372,7 +376,7 @@ class TestDFMPipeline:
         assert len(data_module.Mx) == N
         assert len(data_module.Wx) == N
         
-        # Note: Data should already be preprocessed by user. The transformer is used
+        # Note: Raw data + pipeline pattern - preprocessing happens in setup(). The pipeline is used
         # to extract statistics, not to preprocess. If data is already standardized,
         # the transformer will extract the standardization parameters.
         
@@ -565,7 +569,8 @@ class TestDDFMPipeline:
     def test_ddfm_pipeline_with_columnwise_transformer(self, test_data_path, test_ddfm_config_path, columnwise_transformer):
         """Test complete DDFM pipeline with StandardScaler transformer for statistics extraction.
         
-        Note: Data must be preprocessed by user. Transformer extracts Mx/Wx statistics.
+        Note: Users can provide raw data with a preprocessing pipeline (preprocessing happens in setup()),
+        or preprocessed data. The pipeline also extracts Mx/Wx statistics.
         """
         check_test_files_exist(test_data_path, test_ddfm_config_path)
         
@@ -576,7 +581,7 @@ class TestDDFMPipeline:
         assert model.config is not None
         
         # Step 2: Load data with transformer to extract statistics (Mx/Wx from StandardScaler)
-        # Note: Data should be preprocessed by user before this step
+        # Note: Raw data + pipeline pattern - preprocessing happens in setup()
         data_module = DFMDataModule(
             config=model.config,
             pipeline=columnwise_transformer,  # Extracts Mx/Wx statistics
